from pathlib import Path
import os
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker

# Get the project root directory
BASE_DIR = Path(__file__).resolve().parent.parent.parent

# Ensure this works in both development and deployment environments
if os.path.exists("/app"):
    # Docker/deployment environment
    DB_DIR = Path("/app/storage/db")
else:
    # Development environment
    DB_DIR = BASE_DIR / "storage" / "db"

DB_DIR.mkdir(parents=True, exist_ok=True)

SQLALCHEMY_DATABASE_URL = f"sqlite:///{DB_DIR}/db.sqlite"

engine = create_engine(
    SQLALCHEMY_DATABASE_URL, connect_args={"check_same_thread": False}
)
SessionLocal = sessionmaker(autocommit=False, autoflush=False, bind=engine)
